==> commons-imaging-1.0-20170929-sources.jar: org/apache/commons/imaging/formats/rgbe/InfoHeaderReader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.imaging.formats.rgbe;

import java.io.IOException;
import java.io.InputStream;

class InfoHeaderReader {
    private final InputStream is;

    public InfoHeaderReader(final InputStream is) {
        this.is = is;
    }

    private char read() throws IOException {
        final int result = is.read();
        if (result < 0) {
            throw new IOException("HDR: Unexpected EOF");
        }
        return (char) result;
    }

    public String readNextLine() throws IOException {
        final StringBuilder buffer = new StringBuilder();
        char c;

        while ((c = read()) != '\n') {
            buffer.append(c);
        }

        return buffer.toString();
    }
}

==> commons-imaging-1.0-20200524-sources.jar: org/apache/commons/imaging/formats/rgbe/InfoHeaderReader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.imaging.formats.rgbe;

import java.io.IOException;
import java.io.InputStream;

class InfoHeaderReader {
    private final InputStream is;

    InfoHeaderReader(final InputStream is) {
        this.is = is;
    }

    private char read() throws IOException {
        final int result = is.read();
        if (result < 0) {
            throw new IOException("HDR: Unexpected EOF");
        }
        return (char) result;
    }

    public String readNextLine() throws IOException {
        final StringBuilder buffer = new StringBuilder();
        char c;

        while ((c = read()) != '\n') {
            buffer.append(c);
        }

        return buffer.toString();
    }
}
